@@ -25,8 +25,6 @@ class Config(object):
         try:
             with open(self.configfile, "r") as f:
                 ref_config = json.load(f)
-                print(self.configfile.parent)
-                print(current_path)
                 for key in ref_config:
                     if ref_config[key].startswith("/refs"):
                         if self.configfile.parent == Path("resource"):
@@ -34,7 +32,6 @@ class Config(object):
                         else:
                             ref_config[key] = f"{self.configfile.parent}/{ref_config[key].replace('/refs/','')}"
                     tool_conf[key] = ref_config[key]
-            print(tool_conf)
             return tool_conf
         except IOError:
             print(f"{self.configfile} not exists.")
